Module sovrin::api::pool [] [src]

Functions

sovrin_close_pool_ledger

Closes opened pool ledger, opened nodes connections and frees allocated resources.

sovrin_create_pool_ledger_config

Creates a new local pool ledger configuration that can be used later to connect pool nodes.

sovrin_delete_pool_ledger_config

Deletes created pool ledger configuration.

sovrin_open_pool_ledger

Opens pool ledger and performs connecting to pool nodes.

sovrin_refresh_pool_ledger

Refreshes a local copy of a pool ledger and updates pool nodes connections.