Module sovrin::api::wallet [] [src]

Functions

sovrin_close_wallet

Closes opened wallet and frees allocated resources.

sovrin_create_wallet

Creates a new secure wallet with the given unique name.

sovrin_delete_wallet

Deletes created wallet.

sovrin_open_wallet

Opens the wallet with specific name.

sovrin_register_wallet_type

Registers custom wallet implementation.

sovrin_wallet_set_seq_no_for_value

Sets a seq_no (the corresponding Ledger transaction unique sequence number) for the a value in a secure wallet identified by the given string. The string identifying the value in the wallet is returned when the value is stored in the wallet.