Function sovrin::api::wallet::sovrin_create_wallet [] [src]

#[no_mangle]
pub extern "C" fn sovrin_create_wallet(
    command_handle: i32,
    pool_name: *const c_char,
    name: *const c_char,
    xtype: *const c_char,
    config: *const c_char,
    credentials: *const c_char,
    cb: Option<extern "C" fn(_: i32, _: ErrorCode)>
) -> ErrorCode

Creates a new secure wallet with the given unique name.

Params

pool_name: Name of the pool that corresponds to this wallet. name: Name of the wallet. xtype(optional): Type of the wallet. Defaults to 'default'. Custom types can be registered with sovrin_register_wallet_type call. config(optional): Wallet configuration json. List of supported keys are defined by wallet type. if NULL, then default config will be used. credentials(optional): Wallet credentials json. List of supported keys are defined by wallet type. if NULL, then default config will be used.

Returns

Error code

Errors

Common* Wallet*