Function sovrin::api::wallet::sovrin_open_wallet
[−]
[src]
#[no_mangle]pub extern "C" fn sovrin_open_wallet(
command_handle: i32,
name: *const c_char,
runtime_config: *const c_char,
credentials: *const c_char,
cb: Option<extern "C" fn(_: i32, _: ErrorCode, _: i32)>
) -> ErrorCode
Opens the wallet with specific name.
Wallet with corresponded name must be previously created with sovrin_create_wallet method. It is impossible to open wallet with the same name more than once.
Params
name: Name of the wallet. runtime_config (optional): Runtime wallet configuration json. if NULL, then default runtime_config will be used. Example: { "freshnessTime": string (optional), Amount of minutes to consider wallet value as fresh. Defaults to 24*60. ... List of additional supported keys are defined by wallet type. } credentials(optional): Wallet credentials json. List of supported keys are defined by wallet type. if NULL, then default credentials will be used.
Returns
Handle to opened wallet to use in methods that require wallet access.
Errors
Common* Wallet*